========
img2zarr
========


.. image:: https://img.shields.io/pypi/v/img2zarr.svg
        :target: https://pypi.python.org/pypi/img2zarr

.. image:: https://img.shields.io/travis/manzt/img2zarr.svg
        :target: https://travis-ci.com/manzt/img2zarr

.. image:: https://readthedocs.org/projects/img2zarr/badge/?version=latest
        :target: https://img2zarr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Python package for converting images to zarr chunked arrays.


* Free software: MIT license
* Documentation: https://img2zarr.readthedocs.io.


Features
--------

* TODO
